@@ -60,19 +60,6 @@ mermaid_class <- R6::R6Class(
       self$show_legend <- show_legend
       self$show_color <- show_color
     },
-    append_loops = function() {
-      vertices <- self$network$vertices
-      edges <- self$network$edges
-      if (nrow(edges) > 0L) {
-        edges$loop <- FALSE
-      }
-      disconnected <- setdiff(vertices$name, c(edges$from, edges$to))
-      loops <- data_frame(from = disconnected, to = disconnected)
-      if (nrow(loops)) {
-        loops$loop <- TRUE
-      }
-      self$network$edges <- rbind(edges, loops)
-    },
     produce_class_defs = function() {
       vertices <- self$network$vertices
       status <- c(unique(vertices$status), "none")
@@ -85,11 +72,6 @@ mermaid_class <- R6::R6Class(
         fill
       )
     },
-    produce_link_styles = function() {
-      hide <- c(rep(TRUE, nrow(self$legend) - 1L), self$network$edges$loop)
-      index <- which(hide) - 1L
-      sprintf("  linkStyle %s stroke-width:0px;", index)
-    },
     produce_shape_open = function(type) {
       open <- c("{{", ">", "([", "[")
       names(open) <- c("object", "function", "stem", "pattern")
@@ -111,15 +93,23 @@ mermaid_class <- R6::R6Class(
         name = unique(self$network$vertices$type),
         status = "none"
       )
+      type$name <- ordered(
+        type$name,
+        levels = c("object", "function", "stem", "pattern")
+      )
+      type <- type[order(type$name),, drop = FALSE] # nolint
+      type$name <- as.character(type$name)
       type$open <- self$produce_shape_open(type$name)
       type$close <- self$produce_shape_close(type$name)
       legend <- rbind(status, type)
       legend$label <- gsub("uptodate", "Up to date", legend$name)
       legend <- legend[legend$label != "none",, drop = FALSE] # nolint
-      legend$label <- sprintf("\"%s\"", capitalize(legend$label))
+      legend$label[legend$label == "stem"] <- "Regular target"
+      legend$label[legend$label == "pattern"] <- "Dynamic branches"
+      legend$label <- capitalize(legend$label)
       legend
     },
-    produce_mermaid_vertices = function(data) {
+    produce_mermaid_vertices_text = function(data) {
       sprintf(
         "%s%s%s%s:::%s",
         sprintf("x%s", as.character(map_chr(data$name, hash_object))),
@@ -129,37 +119,26 @@ mermaid_class <- R6::R6Class(
         data$status
       )
     },
-    produce_mermaid_vertices_graph = function(side) {
-      out <- self$network$edges
-      other <- if_any(identical(side, "from"), "to", "from")
-      out[[other]] <- NULL
-      out$name <- out[[side]]
-      out[[side]] <- NULL
-      vertices <- self$network$vertices
-      out$id <- seq_len(nrow(out))
-      out <- merge(x = out, y = vertices, all = FALSE, sort = FALSE)
-      out <- out[order(out$id),, drop = FALSE] # nolint
-      out$id <- NULL
-      out$open <- self$produce_shape_open(out$type)
-      out$close <- self$produce_shape_close(out$type)
-      self$produce_mermaid_vertices(out)
-    },
     produce_mermaid_lines_graph = function() {
-      self$append_loops()
-      from <- produce_mermaid_vertices_graph(side = "from")
-      to <- produce_mermaid_vertices_graph(side = "to")
-      out <- sprintf("    %s --> %s", from, to)
+      vertices <- self$network$vertices
+      vertices$open <- self$produce_shape_open(vertices$type)
+      vertices$close <- self$produce_shape_close(vertices$type)
+      text <- self$produce_mermaid_vertices_text(vertices)
+      names(text) <- self$network$vertices$name
+      edges <- self$network$edges
+      disconnected <- setdiff(vertices$name, c(edges$from, edges$to))
+      disconnected <- unname(text[disconnected])
+      edges$from <- unname(text[edges$from])
+      edges$to <- unname(text[edges$to])
+      out <- c(
+        sprintf("    %s --> %s", edges$from, edges$to),
+        paste0("    ", disconnected)
+      )
       out <- c("  subgraph Graph", "    direction LR", out, "  end")
     },
     produce_mermaid_lines_legend = function() {
-      vertices <- produce_mermaid_vertices(self$legend)
-      if (length(vertices) == 1L) {
-        vertices <- c(vertices, vertices)
-      }
-      from <- vertices[-length(vertices)]
-      to <- vertices[-1]
-      out <- sprintf("    %s --- %s", from, to)
-      out <- c("  subgraph Legend", "    direction LR", out, "  end")
+      vertices <- produce_mermaid_vertices_text(self$legend)
+      c("  subgraph Legend", paste0("    ", vertices), "  end")
     },
     produce_graph_styles = function(show_legend) {
       c(
@@ -186,19 +165,13 @@ mermaid_class <- R6::R6Class(
         self$produce_class_defs(),
         character(0)
       )
-      link_styles <- if_any(
-        self$show_legend,
-        self$produce_link_styles(),
-        character(0)
-      )
       graph_styles <- self$produce_graph_styles(self$show_legend)
       c(
         "graph LR",
         graph_styles,
         legend,
         graph,
-        class_defs,
-        link_styles
+        class_defs
       )
     },
     update_extra = function() {
