@@ -91,12 +91,22 @@ pipeline_set_reference <- function(pipeline, target) {
 pipeline_initialize_references_children <- function(
   pipeline,
   name_parent,
-  names_children
+  names_children,
+  type
 ) {
   envir <- .subset2(pipeline, "targets")
-  for (index in seq_along(names_children)) {
+  index <- 1L
+  n <- length(names_children)
+  bar <- cli_local_progress_bar_init(
+    label = sprintf("creating %s references", type),
+    total = n
+  )
+  on.exit(cli_local_progress_bar_destroy(bar = bar))
+  while (index <= n) {
     name <- .subset(names_children, index)
     envir[[name]] <- reference_new(parent = name_parent, index = index)
+    index <- index + 1L
+    cli_local_progress_bar_update(bar = bar, index = index)
   }
   NULL
 }
