@@ -12,11 +12,14 @@ resources_feather_new <- function(
   compression = NULL,
   compression_level = NULL
 ) {
-  force(compression)
-  force(compression_level)
-  enclass(environment(), c("tar_resources_feather", "tar_resources"))
+  out <- new.env(parent = emptyenv(), hash = FALSE)
+  out$compression <- compression
+  out$compression_level <- compression_level
+  enclass(out, resouces_feather_s3_class)
 }
 
+resouces_feather_s3_class <- c("tar_resources_feather", "tar_resources")
+
 #' @export
 resources_validate.tar_resources_feather <- function(resources) {
   tar_assert_scalar(resources$compression)
