@@ -12,11 +12,14 @@ resources_future_new <- function(
   plan = NULL,
   resources = NULL
 ) {
-  force(plan)
-  force(resources)
-  enclass(environment(), c("tar_resources_future", "tar_resources"))
+  out <- new.env(parent = emptyenv(), hash = FALSE)
+  out$plan <- plan
+  out$resources <- resources
+  enclass(out, resources_future_s3_class)
 }
 
+resources_future_s3_class <- c("tar_resources_future", "tar_resources")
+
 #' @export
 resources_validate.tar_resources_future <- function(resources) {
   tar_assert_list(resources$resources)
