@@ -72,7 +72,6 @@ tar_make_clustermq <- function(
   tar_assert_package("clustermq (>= 0.9.2)")
   tar_assert_scalar(shortcut)
   tar_assert_lgl(shortcut)
-  tar_assert_flag(reporter, tar_reporters_make())
   tar_assert_scalar(workers)
   tar_assert_dbl(workers)
   tar_assert_ge(workers, 1)
@@ -86,10 +85,6 @@ tar_make_clustermq <- function(
   tar_assert_scalar(seconds_meta_upload)
   tar_assert_none_na(seconds_meta_upload)
   tar_assert_ge(seconds_meta_upload, 0)
-  tar_assert_dbl(seconds_reporter)
-  tar_assert_scalar(seconds_reporter)
-  tar_assert_none_na(seconds_reporter)
-  tar_assert_ge(seconds_reporter, 0)
   tar_deprecate_seconds_interval(seconds_interval)
   if_any(
     is.null(garbage_collection),
@@ -101,6 +96,7 @@ tar_make_clustermq <- function(
       "Please have a look at its documentation."
     )
   )
+  reporter <- tar_make_reporter(reporter)
   targets_arguments <- list(
     path_store = store,
     names_quosure = rlang::enquo(names),
@@ -108,7 +104,6 @@ tar_make_clustermq <- function(
     reporter = reporter,
     seconds_meta_append = seconds_meta_append,
     seconds_meta_upload = seconds_meta_upload,
-    seconds_reporter = seconds_reporter,
     workers = workers,
     log_worker = log_worker
   )
@@ -133,7 +128,6 @@ tar_make_clustermq_inner <- function(
   reporter,
   seconds_meta_append,
   seconds_meta_upload,
-  seconds_reporter,
   workers,
   log_worker
 ) {
@@ -147,7 +141,6 @@ tar_make_clustermq_inner <- function(
     reporter = reporter,
     seconds_meta_append = seconds_meta_append,
     seconds_meta_upload = seconds_meta_upload,
-    seconds_reporter = seconds_reporter,
     envir = tar_option_get("envir"),
     workers = workers,
     log_worker = log_worker
