@@ -1,8 +1,8 @@
-#' @title Load a saved workspace and seed for debugging.
+#' @title Load a locally saved workspace and seed for debugging.
 #' @export
 #' @family debug
-#' @description Load the packages, workspace, and random number generator seed
-#'   of target attempted with a workspace file.
+#' @description Load the packages, environment, and random number generator
+#'   seed of a target.
 #' @details If you activate workspaces through the `workspaces` argument
 #'   of [tar_option_set()], then under the circumstances you specify,
 #'   `targets` will save a special workspace file to a location in
@@ -12,6 +12,13 @@
 #'   are still in the data store (usually files in `_targets/objects/`).
 #'   When you are done debugging, you can remove the workspace files
 #'   using `tar_destroy(destroy = "workspaces")`.
+#'
+#'   If `tar_option_get("repository_meta")` is `"aws"` or `"gcp"`, then
+#'   [tar_make()] uploads workspaces to the bucket and prefix provided.
+#'   Download one of these workspaces with [tar_workspace_download()].
+#'   Downloaded workspaces can be loaded the usual way with
+#'   [tar_workspace()], and you should see them in
+#'   character vector returned by [tar_workspaces()].
 #' @return This function returns `NULL`, but it does load
 #'   the target's required packages, as well as multiple objects
 #'   into the environment (`envir` argument) in order to replicate the
@@ -33,7 +40,8 @@
 #' tar_dir({ # tar_dir() runs code from a temp dir for CRAN.
 #' tmp <- sample(1)
 #' tar_script({
-#'   tar_option_set(workspace_on_error = TRUE)
+#'   library(targets)
+#'   library(tarchetypes)
 #'   list(
 #'     tar_target(x, "loaded"),
 #'     tar_target(y, stop(x))
@@ -71,7 +79,7 @@ tar_workspace <- function(
     workspace_load_packages(workspace)
   }
   if (source) {
-    eval(parse(text = readLines(script)), envir = envir)
+    eval(parse(text = readLines(script), keep.source = TRUE), envir = envir)
   }
   workspace_set_seed(workspace)
   invisible()
