@@ -129,7 +129,8 @@ callr_inner <- function(
         store = store,
         fun = fun,
         pid_parent = pid_parent
-      ),
+      )
+      ,
       error = function(condition) {
         trace <- .traceback(x = 3L)
         result$condition <- targets::tar_condition_traced(
@@ -195,17 +196,18 @@ tar_callr_inner_try <- function(
     script = script,
     store = store,
     fun = fun,
-    pid_parent = pid_parent
+    pid_parent = pid_parent,
+    reporter = targets_arguments$reporter
   )
   envir <- if_any(is.null(envir), parent, envir)
   tar_options$set_envir(envir = envir)
   targets <- eval(parse(file = script, keep.source = TRUE), envir = envir)
   targets_arguments$pipeline <- pipeline_from_list(targets)
   pipeline_validate_lite(targets_arguments$pipeline)
-  do.call(targets_function, targets_arguments)
+  suppressPackageStartupMessages(do.call(targets_function, targets_arguments))
 }
 
-callr_set_runtime <- function(script, store, fun, pid_parent) {
+callr_set_runtime <- function(script, store, fun, pid_parent, reporter) {
   tar_runtime$script <- script
   tar_runtime$store <- store
   tar_runtime$working_directory <- getwd()
@@ -218,7 +220,7 @@ callr_set_runtime <- function(script, store, fun, pid_parent) {
   )
   tar_runtime$pid_parent <- pid_parent
   tar_runtime$inventories <- list()
-  runtime_set_file_info(tar_runtime, store)
+  tar_runtime$progress_bar <- identical(as.character(reporter), "balanced")
 }
 
 callr_prepare_arguments <- function(callr_function, callr_arguments) {
