@@ -36,14 +36,16 @@ tar_test("aws file gets stored", {
       max_tries = 1L
     )
   )
+  expect_true(file.exists("example_aws_file.txt"))
+  unlink("example_aws_file.txt")
   expect_false(file.exists("example_aws_file.txt"))
   unlink("_targets/scratch", recursive = TRUE)
   expect_equal(tar_read(y), "x_lines")
-  expect_equal(length(list.files("_targets/scratch/")), 0L)
+  expect_length(list.files("_targets/scratch/"), 0L)
   expect_false(file.exists("_targets/scratch/x"))
   expect_false(file.exists("example_aws_file.txt"))
   path <- tar_read(x)
-  expect_equal(length(list.files("_targets/scratch/")), 0L)
+  expect_length(list.files("_targets/scratch/"), 0L)
   expect_false(file.exists("_targets/scratch/x"))
   expect_true(file.exists("example_aws_file.txt"))
   expect_equal(readLines("example_aws_file.txt"), "x_lines")
@@ -93,14 +95,16 @@ tar_test("aws file gets stored with transient memory", {
       max_tries = 1L
     )
   )
+  expect_true(file.exists("example_aws_file.txt"))
+  unlink("example_aws_file.txt")
   expect_false(file.exists("example_aws_file.txt"))
   unlink("_targets/scratch", recursive = TRUE)
   expect_equal(tar_read(y), "x_lines")
-  expect_equal(length(list.files("_targets/scratch/")), 0L)
+  expect_length(list.files("_targets/scratch/"), 0L)
   expect_false(file.exists("_targets/scratch/x"))
   expect_false(file.exists("example_aws_file.txt"))
   path <- tar_read(x)
-  expect_equal(length(list.files("_targets/scratch/")), 0L)
+  expect_length(list.files("_targets/scratch/"), 0L)
   expect_false(file.exists("_targets/scratch/x"))
   expect_true(file.exists("example_aws_file.txt"))
   expect_equal(readLines("example_aws_file.txt"), "x_lines")
@@ -221,6 +225,7 @@ tar_test("aws_file format with a custom data store", {
   expr <- tar_tidy_eval(expr, environment(), TRUE)
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   tar_make(callr_function = NULL, envir = tar_option_get("envir"))
+  unlink("example_aws_file.txt")
   expect_true(file.exists("custom_targets_store"))
   expect_false(file.exists(path_store_default()))
   expect_true(
@@ -231,10 +236,10 @@ tar_test("aws_file format with a custom data store", {
     )
   )
   expect_equal(tar_read(y), "x_lines")
-  expect_equal(length(list.files("custom_targets_store/scratch/")), 0L)
+  expect_length(list.files("custom_targets_store/scratch/"), 0L)
   expect_false(file.exists("example_aws_file.txt"))
   path <- tar_read(x)
-  expect_equal(length(list.files("custom_targets_store/scratch/")), 0L)
+  expect_length(list.files("custom_targets_store/scratch/"), 0L)
   expect_true(file.exists("example_aws_file.txt"))
   expect_equal(readLines("example_aws_file.txt"), "x_lines")
   tmp <- tempfile()
@@ -290,6 +295,7 @@ tar_test("aws_file format file with different region", {
   expr <- tar_tidy_eval(expr, environment(), TRUE)
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   tar_make(callr_function = NULL, envir = tar_option_get("envir"))
+  unlink("example_aws_file.txt")
   expect_true(
     aws_s3_exists(
       bucket = bucket_name,
@@ -300,11 +306,11 @@ tar_test("aws_file format file with different region", {
   )
   unlink("_targets/scratch", recursive = TRUE)
   expect_equal(tar_read(y), "x_lines")
-  expect_equal(length(list.files("_targets/scratch/")), 0L)
+  expect_length(list.files("_targets/scratch/"), 0L)
   expect_false(file.exists("_targets/scratch/x"))
   expect_false(file.exists("example_aws_file.txt"))
   path <- tar_read(x)
-  expect_equal(length(list.files("_targets/scratch/")), 0L)
+  expect_length(list.files("_targets/scratch/"), 0L)
   expect_false(file.exists("_targets/scratch/x"))
   expect_true(file.exists("example_aws_file.txt"))
   expect_equal(readLines("example_aws_file.txt"), "x_lines")
@@ -331,60 +337,3 @@ tar_test("aws_file format file with different region", {
   expect_equal(readLines(tmp), "x_lines")
   unlink("example_aws_file.txt")
 })
-
-tar_test("file_fast gets converted to file", {
-  skip_if_no_aws()
-  bucket_name <- random_bucket_name()
-  s3 <- paws.storage::s3()
-  s3$create_bucket(Bucket = bucket_name)
-  on.exit(aws_s3_delete_bucket(bucket_name))
-  expr <- quote({
-    tar_option_set(memory = "persistent", resources = tar_resources(
-      aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
-    ))
-    evalq(
-      write_local_file <- function(lines) {
-        writeLines(lines, "example_aws_file.txt")
-        "example_aws_file.txt"
-      }, envir = tar_option_get("envir")
-    )
-    list(
-      tar_target(
-        x,
-        write_local_file("x_lines"),
-        format = "file_fast",
-        repository = "aws"
-      ),
-      tar_target(y, readLines(x))
-    )
-  })
-  expr <- tar_tidy_eval(expr, environment(), TRUE)
-  eval(as.call(list(`tar_script`, expr, ask = FALSE)))
-  tar_make(callr_function = NULL, envir = tar_option_get("envir"))
-  expect_true(
-    aws_s3_exists(
-      bucket = bucket_name,
-      key = "_targets/objects/x",
-      max_tries = 1L
-    )
-  )
-  expect_false(file.exists("example_aws_file.txt"))
-  unlink("_targets/scratch", recursive = TRUE)
-  expect_equal(tar_read(y), "x_lines")
-  expect_equal(length(list.files("_targets/scratch/")), 0L)
-  expect_false(file.exists("_targets/scratch/x"))
-  expect_false(file.exists("example_aws_file.txt"))
-  path <- tar_read(x)
-  expect_equal(length(list.files("_targets/scratch/")), 0L)
-  expect_false(file.exists("_targets/scratch/x"))
-  expect_true(file.exists("example_aws_file.txt"))
-  expect_equal(readLines("example_aws_file.txt"), "x_lines")
-  tmp <- tempfile()
-  aws_s3_download(
-    key = "_targets/objects/x",
-    bucket = bucket_name,
-    file = tmp,
-    max_tries = 1L
-  )
-  expect_equal(readLines(tmp), "x_lines")
-})
