@@ -353,12 +353,12 @@ tar_test("gcp_gcs_list_md5s()", {
     )
   }
   out <- gcp_gcs_list_md5s(prefix = "", bucket = bucket)
-  expect_equal(length(out), 4L)
+  expect_length(out, 4L)
   expect_equal(sort(names(out)), sort(c("w", "x", "y", "z")))
   for (etag in out) {
     expect_true(is.character(etag))
-    expect_true(!anyNA(etag))
-    expect_equal(length(etag), 1L)
+    expect_false(anyNA(etag))
+    expect_length(etag, 1L)
     expect_gt(nchar(etag), 10L)
   }
 })
