@@ -114,7 +114,8 @@ tar_test("file_update_hash()", {
   expect_false(anyNA(file_time_posixct(file$time)))
   expect_true(inherits(file_time_posixct(file$time), "POSIXct"))
   expect_true(is.character(file$size))
-  expect_equal(nchar(file$size), 16L)
+  expect_true(grepl("^s", file$size))
+  expect_true(grepl("b$", file$size))
   expect_true(is.numeric(file$bytes))
   expect_true(is.finite(file$bytes))
   expect_length(file$bytes, 1L)
@@ -135,7 +136,8 @@ tar_test("file_update_info()", {
   expect_false(anyNA(file_time_posixct(file$time)))
   expect_true(inherits(file_time_posixct(file$time), "POSIXct"))
   expect_true(is.character(file$size))
-  expect_equal(nchar(file$size), 16L)
+  expect_true(grepl("^s", file$size))
+  expect_true(grepl("b$", file$size))
   expect_true(is.numeric(file$bytes))
   expect_true(is.finite(file$bytes))
   expect_length(file$bytes, 1L)
@@ -160,7 +162,8 @@ tar_test("file_update_hash() where two files exist", {
   expect_false(anyNA(file_time_posixct(file$time)))
   expect_true(inherits(file_time_posixct(file$time), "POSIXct"))
   expect_true(is.character(file$size))
-  expect_equal(nchar(file$size), 16L)
+  expect_true(grepl("^s", file$size))
+  expect_true(grepl("b$", file$size))
   expect_true(is.finite(file$bytes))
   expect_length(file$bytes, 1L)
   expect_length(file$time, 1L)
@@ -183,7 +186,8 @@ tar_test("file_update_hash() where one file does not exist", {
   expect_false(anyNA(file_time_posixct(file$time)))
   expect_true(inherits(file_time_posixct(file$time), "POSIXct"))
   expect_true(is.character(file$size))
-  expect_equal(nchar(file$size), 16L)
+  expect_true(grepl("^s", file$size))
+  expect_true(grepl("b$", file$size))
   expect_true(is.finite(file$bytes))
   expect_length(file$bytes, 1L)
   expect_length(file$time, 1L)
@@ -205,7 +209,8 @@ tar_test("file_update_hash() where neither file exists", {
   expect_false(anyNA(file_time_posixct(file$time)))
   expect_true(inherits(file_time_posixct(file$time), "POSIXct"))
   expect_true(is.character(file$size))
-  expect_equal(nchar(file$size), 16L)
+  expect_true(grepl("^s", file$size))
+  expect_true(grepl("b$", file$size))
 })
 
 tar_test("all files are hashed", {
