@@ -160,6 +160,12 @@ tar_test("validate non-null script", {
   expect_silent(runtime_validate(x))
 })
 
+tar_test("validate non-null progress_bar", {
+  x <- runtime_new()
+  x$progress_bar <- TRUE
+  expect_silent(runtime_validate(x))
+})
+
 tar_test("detect bad script", {
   x <- runtime_new()
   x$script <- FALSE
@@ -189,7 +195,7 @@ tar_test("runtime_set_file_info()", {
   dir_create(path_objects_dir(store))
   writeLines("x", path_objects(store, "x"))
   writeLines("y", path_objects(store, "y"))
-  runtime_set_file_info(x, store)
+  runtime_set_file_info(x, store, c("x", "y"))
   expect_true(is.character(x$file_info$path))
   for (field in c("size", "mtime_numeric")) {
     expect_true(is.numeric(x$file_info[[field]]))
